package ActiveState::Scineplex;

use strict;

our %SCLEX_LANG_CODE = (
    css    => 38,
    html   =>  4,
    perl   =>  6,
    ruby   => 22,
    vbscript => 28,
    xslt   => 55,
);

our %SCE_TOKEN = (
    css => {
         0 => "SCE_CSS_DEFAULT",
         1 => "SCE_CSS_TAG",
         2 => "SCE_CSS_CLASS",
         3 => "SCE_CSS_PSEUDOCLASS",
         4 => "SCE_CSS_UNKNOWN_PSEUDOCLASS",
         5 => "SCE_CSS_OPERATOR",
         6 => "SCE_CSS_IDENTIFIER",
         7 => "SCE_CSS_UNKNOWN_IDENTIFIER",
         8 => "SCE_CSS_VALUE",
         9 => "SCE_CSS_COMMENT",
        10 => "SCE_CSS_ID",
        11 => "SCE_CSS_IMPORTANT",
        12 => "SCE_CSS_DIRECTIVE",
        13 => "SCE_CSS_DOUBLESTRING",
        14 => "SCE_CSS_SINGLESTRING",
    },
    html => {
         0 => "SCE_H_DEFAULT",
         1 => "SCE_H_TAG",
         2 => "SCE_H_TAGUNKNOWN",
         3 => "SCE_H_ATTRIBUTE",
         4 => "SCE_H_ATTRIBUTEUNKNOWN",
         5 => "SCE_H_NUMBER",
         6 => "SCE_H_DOUBLESTRING",
         7 => "SCE_H_SINGLESTRING",
         8 => "SCE_H_OTHER",
         9 => "SCE_H_COMMENT",
        10 => "SCE_H_ENTITY",
        11 => "SCE_H_TAGEND",
        12 => "SCE_H_XMLSTART",
        13 => "SCE_H_XMLEND",
        14 => "SCE_H_SCRIPT",
        15 => "SCE_H_ASP",
        16 => "SCE_H_ASPAT",
        17 => "SCE_H_CDATA",
        18 => "SCE_H_QUESTION",
        19 => "SCE_H_VALUE",
        20 => "SCE_H_XCCOMMENT",
        21 => "SCE_H_SGML_DEFAULT",
        22 => "SCE_H_SGML_COMMAND",
        23 => "SCE_H_SGML_1ST_PARAM",
        24 => "SCE_H_SGML_DOUBLESTRING",
        25 => "SCE_H_SGML_SIMPLESTRING",
        26 => "SCE_H_SGML_ERROR",
        27 => "SCE_H_SGML_SPECIAL",
        28 => "SCE_H_SGML_ENTITY",
        29 => "SCE_H_SGML_COMMENT",
        30 => "SCE_H_SGML_1ST_PARAM_COMMENT",
        31 => "SCE_H_SGML_BLOCK_DEFAULT",
    },
    perl => {
         0 => "SCE_PL_DEFAULT",
         1 => "SCE_PL_ERROR",
         2 => "SCE_PL_COMMENTLINE",
         3 => "SCE_PL_POD",
         4 => "SCE_PL_NUMBER",
         5 => "SCE_PL_WORD",
         6 => "SCE_PL_STRING",
         7 => "SCE_PL_CHARACTER",
         8 => "SCE_PL_PUNCTUATION",
         9 => "SCE_PL_PREPROCESSOR",
        10 => "SCE_PL_OPERATOR",
        11 => "SCE_PL_IDENTIFIER",
        12 => "SCE_PL_SCALAR",
        13 => "SCE_PL_ARRAY",
        14 => "SCE_PL_HASH",
        15 => "SCE_PL_SYMBOLTABLE",
        16 => "SCE_PL_VARIABLE_INDEXER",
        17 => "SCE_PL_REGEX",
        18 => "SCE_PL_REGSUBST",
        19 => "SCE_PL_LONGQUOTE",
        20 => "SCE_PL_BACKTICKS",
        21 => "SCE_PL_DATASECTION",
        22 => "SCE_PL_HERE_DELIM",
        23 => "SCE_PL_HERE_Q",
        24 => "SCE_PL_HERE_QQ",
        25 => "SCE_PL_HERE_QX",
        26 => "SCE_PL_STRING_Q",
        27 => "SCE_PL_STRING_QQ",
        28 => "SCE_PL_STRING_QX",
        29 => "SCE_PL_STRING_QR",
        30 => "SCE_PL_STRING_QW",
        31 => "SCE_PL_SUB",
        40 => "SCE_PL_SUB_ARGS",
        41 => "SCE_PL_UNKNOWN_FIELD",
        42 => "SCE_PL_STDIN",
        43 => "SCE_PL_STDOUT",
        44 => "SCE_PL_STDERR",
        45 => "SCE_PL_FORMAT",
    },
    ruby => {
         0 => "SCE_RB_DEFAULT",
         1 => "SCE_RB_ERROR",
         2 => "SCE_RB_COMMENTLINE",
         3 => "SCE_RB_POD",
         4 => "SCE_RB_NUMBER",
         5 => "SCE_RB_WORD",
         6 => "SCE_RB_STRING",
         7 => "SCE_RB_CHARACTER",
         8 => "SCE_RB_CLASSNAME",
         9 => "SCE_RB_DEFNAME",
        10 => "SCE_RB_OPERATOR",
        11 => "SCE_RB_IDENTIFIER",
        12 => "SCE_RB_REGEX",
        13 => "SCE_RB_GLOBAL",
        14 => "SCE_RB_SYMBOL",
        15 => "SCE_RB_MODULE_NAME",
        16 => "SCE_RB_INSTANCE_VAR",
        17 => "SCE_RB_CLASS_VAR",
        18 => "SCE_RB_BACKTICKS",
        19 => "SCE_RB_DATASECTION",
        20 => "SCE_RB_HERE_DELIM",
        21 => "SCE_RB_HERE_Q",
        22 => "SCE_RB_HERE_QQ",
        23 => "SCE_RB_HERE_QX",
        24 => "SCE_RB_STRING_Q",
        25 => "SCE_RB_STRING_QQ",
        26 => "SCE_RB_STRING_QX",
        27 => "SCE_RB_STRING_QR",
        28 => "SCE_RB_STRING_QW",
        29 => "SCE_RB_WORD_DEMOTED",
        30 => "SCE_RB_STDIN",
        31 => "SCE_RB_STDOUT",
        40 => "SCE_RB_STDERR",
    },
    vbscript => {
         0 => "SCE_B_DEFAULT",
         1 => "SCE_B_COMMENT",
         2 => "SCE_B_NUMBER",
         3 => "SCE_B_KEYWORD",
         4 => "SCE_B_STRING",
         5 => "SCE_B_PREPROCESSOR",
         6 => "SCE_B_OPERATOR",
         7 => "SCE_B_IDENTIFIER",
         8 => "SCE_B_DATE",
         9 => "SCE_B_STRINGEOL",
        10 => "SCE_B_KEYWORD2",
        11 => "SCE_B_KEYWORD3",
        12 => "SCE_B_KEYWORD4",
    },
    xslt => {
         0 => "SCE_XML_PROLOG",
         0 => "SCE_XML_DEFAULT",
         1 => "SCE_XML_START_TAG_OPEN",
         2 => "SCE_XML_START_TAG_NAME",
         3 => "SCE_XML_START_TAG_CLOSE",
         4 => "SCE_XML_START_TAG_EMPTY_CLOSE",
         5 => "SCE_XML_START_TAG_ATTR_NAME",
         6 => "SCE_XML_START_TAG_ATTR_EQUALS",
         7 => "SCE_XML_START_TAG_ATTR_QUOT_OPEN",
         8 => "SCE_XML_START_TAG_ATTR_QUOT_CONTENT",
         9 => "SCE_XML_START_TAG_ATTR_QUOT_CLOSE",
        10 => "SCE_XML_START_TAG_ATTR_APOS_OPEN",
        11 => "SCE_XML_START_TAG_ATTR_APOS_CONTENT",
        12 => "SCE_XML_START_TAG_ATTR_APOS_CLOSE",
        13 => "SCE_XML_END_TAG_OPEN",
        14 => "SCE_XML_END_TAG_NAME",
        15 => "SCE_XML_END_TAG_CLOSE",
        16 => "SCE_XML_START_TAG_ATTR_NUMBER",
        17 => "SCE_XML_ENTITY_REF",
        18 => "SCE_XML_CHAR_REF",
        19 => "SCE_XML_DATA_NEWLINE",
        20 => "SCE_XML_DATA_CHARS",
        21 => "SCE_XML_CDATA_SECT_OPEN",
        22 => "SCE_XML_CDATA_SECT_CONTENT",
        23 => "SCE_XML_CDATA_SECT_CLOSE",
        24 => "SCE_XML_COMMENT_OPEN",
        25 => "SCE_XML_COMMENT_CONTENT",
        26 => "SCE_XML_COMMENT_CLOSE",
        27 => "SCE_XML_PI_OPEN",
        28 => "SCE_XML_PI_CONTENT",
        29 => "SCE_XML_PI_CLOSE",
        30 => "SCE_XML_XML_DECL_OPEN",
        31 => "SCE_XML_XML_DECL_CONTENT",
        40 => "SCE_XML_XML_DECL_CLOSE",
        41 => "SCE_XML_BOM",
        48 => "SCE_XML_START_TAG_WHITE_SPACE",
        49 => "SCE_XML_START_TAG_ATTR_UNQUOTED",
        50 => "SCE_XML_END_TAG_WHITE_SPACE",
        51 => "SCE_XML_DECLARATION_OPEN",
        52 => "SCE_XML_DECLARATION_TYPE",
        53 => "SCE_XML_DECLN_WHITE_SPACE",
        54 => "SCE_XML_DECLN_NAME",
        55 => "SCE_XML_DECLN_CLOSE",
        56 => "SCE_XML_DECLN_QUOT_CONTENT",
        57 => "SCE_XML_DECLN_APOS_CONTENT",
        58 => "SCE_XML_DECLN_DATA_CHARS",
    },
);

1;
